check_var
==================================================

.. currentmodule:: skchange.costs.utils

.. autofunction:: check_var

.. include:: skchange.costs.utils.check_var.examples

.. raw:: html

    <div class="clearer"></div>